@@ -25,7 +25,6 @@
 #include <QMouseEvent>
 #include <QTimer>
 #include <QMap>
-#include <vlc/vlc.h>
 #include <vlc/libvlc_version.h>
 
 #include "../configuration.h"
@@ -64,18 +63,18 @@ bool VlcMediaWidget::init()
 
 	if (vlcInstance == NULL) {
 		qFatal("Cannot create vlc instance %s", qPrintable(libvlc_errmsg()));
-		delete argv;
+		delete[] argv;
 		return false;
 	}
 
 	if (argc) {
 		QString log = "Using libVLC with args:";
 		for (int i = 0; i < argc; i++)
-			log += " " + QLatin1String(argv[i]);
+			log += ' ' + QLatin1String(argv[i]);
 
 		qCDebug(logVlc, "%s", qPrintable(log));
 	}
-	delete argv;
+	delete[] argv;
 
 	vlcMediaPlayer = libvlc_media_player_new(vlcInstance);
 
@@ -95,7 +94,7 @@ bool VlcMediaWidget::init()
 
 	for (uint i = 0; i < (sizeof(eventTypes) / sizeof(eventTypes[0])); ++i) {
 		if (libvlc_event_attach(eventManager, eventTypes[i], vlcEventHandler, this) != 0) {
-			qCCritical(logMediaWidget, "Cannot attach event handler %s", qPrintable(eventTypes[i]));
+			qCCritical(logMediaWidget, "Cannot attach event handler %d", eventTypes[i]);
 			return false;
 		}
 	}
@@ -279,6 +278,9 @@ void VlcMediaWidget::play(const MediaSource &source)
 	QByteArray url = source.getUrl().toEncoded();
 	playingDvd = false;
 
+	trackNumber = 1;
+	urlIsAudioCd = false;
+
 	switch (source.getType()) {
 	case MediaSource::Url:
 		if (url.endsWith(".iso")) {
@@ -287,6 +289,8 @@ void VlcMediaWidget::play(const MediaSource &source)
 
 		break;
 	case MediaSource::AudioCd:
+		urlIsAudioCd = true;
+
 		if (url.size() >= 7) {
 			url.replace(0, 4, "cdda");
 		} else {
@@ -315,12 +319,28 @@ void VlcMediaWidget::play(const MediaSource &source)
 		break;
 	}
 
-	libvlc_media_t *vlcMedia = libvlc_media_new_location(vlcInstance, url.constData());
+	typeOfDevice = url.constData();
 
+	vlcMedia = libvlc_media_new_location(vlcInstance, typeOfDevice);
+	if (urlIsAudioCd)
+		libvlc_media_add_option(vlcMedia, "cdda-track=1");
+
+	if (makePlay() < 0) {
+		stop();
+		return;
+	}
+
+	setCursor(Qt::BlankCursor);
+	setCursor(Qt::ArrowCursor);
+	timer->start(1000);
+	setMouseTracking(true);
+}
+
+int VlcMediaWidget::makePlay()
+{
 	if (vlcMedia == NULL) {
 		libvlc_media_player_stop(vlcMediaPlayer);
-		qCWarning(logMediaWidget, "Cannot create media %s", qPrintable(source.getUrl().toDisplayString()));
-		return;
+		return -1;
 	}
 
 	libvlc_event_manager_t *eventManager = libvlc_media_event_manager(vlcMedia);
@@ -328,25 +348,61 @@ void VlcMediaWidget::play(const MediaSource &source)
 
 	for (uint i = 0; i < (sizeof(eventTypes) / sizeof(eventTypes[0])); ++i) {
 		if (libvlc_event_attach(eventManager, eventTypes[i], vlcEventHandler, this) != 0) {
-			qCWarning(logMediaWidget, "Cannot attach event handler %s", qPrintable(eventTypes[i]));
+			qCWarning(logMediaWidget, "Cannot attach event handler %d", eventTypes[i]);
 		}
 	}
 
 	libvlc_media_player_set_media(vlcMediaPlayer, vlcMedia);
 	libvlc_media_release(vlcMedia);
+	vlcMedia = NULL;
 
-//	FIXME! subtitleUrl is only available for MediaSourceUrl private class
-//	if (source.subtitleUrl.isValid())
-//		setExternalSubtitle(source.subtitleUrl);
+	/*
+	 * FIXME: This is mostly a boilerplate as, at least with vlc 3,
+	 * this function always return -1
+         */
+	if (urlIsAudioCd)
+		numTracks = libvlc_audio_get_track_count(vlcMediaPlayer);
 
-	if (libvlc_media_player_play(vlcMediaPlayer) != 0) {
-		qCWarning(logMediaWidget, "Cannot play media %s", qPrintable(source.getUrl().toDisplayString()));
+	return libvlc_media_player_play(vlcMediaPlayer);
+}
+
+void VlcMediaWidget::playDirection(int direction)
+{
+	QString strBuf = "cdda-track=";
+	libvlc_state_t state;
+	int oldTrackNumber = trackNumber;
+
+	if (direction == -1)
+		trackNumber--;
+	else
+		trackNumber++;
+
+	if (numTracks > 0 && trackNumber > numTracks)
+		trackNumber = numTracks;
+	if (trackNumber < 1)
+		trackNumber = 1;
+
+	strBuf += QString::number(trackNumber);
+
+	if (vlcMedia != NULL)
+		libvlc_media_release(vlcMedia);
+
+	vlcMedia = libvlc_media_new_location(vlcInstance, typeOfDevice);
+	libvlc_media_add_option(vlcMedia, strBuf.toUtf8());
+
+	if (makePlay() < 0)
+		stop();
+
+	do {
+		state = libvlc_media_player_get_state (vlcMediaPlayer);
+	} while(state != libvlc_Playing &&
+		state != libvlc_Error &&
+		state != libvlc_Ended );
+
+	if (state != libvlc_Playing) {
+		stop();
+		trackNumber = oldTrackNumber;
 	}
-
-	setCursor(Qt::BlankCursor);
-	setCursor(Qt::ArrowCursor);
-	timer->start(1000);
-	setMouseTracking(true);
 }
 
 void VlcMediaWidget::stop()
@@ -427,7 +483,7 @@ void VlcMediaWidget::setExternalSubtitle(const QUrl &url)
 		qCWarning(logMediaWidget, "Cannot set subtitle file %s", qPrintable(fname));
 #else
 	if (libvlc_video_set_subtitle_file(vlcMediaPlayer,
-					   qPrintable(fname)) == 0)
+					   fname.toLocal8Bit().constData()) == 0)
 		qCWarning(logMediaWidget, "Cannot set subtitle file %s", qPrintable(fname));
 #endif
 }
@@ -452,7 +508,10 @@ bool VlcMediaWidget::jumpToPreviousChapter()
 {
 	int currentTitle = libvlc_media_player_get_title(vlcMediaPlayer);
 	int currentChapter = libvlc_media_player_get_chapter(vlcMediaPlayer);
-	libvlc_media_player_previous_chapter(vlcMediaPlayer);
+	if (urlIsAudioCd)
+		playDirection(-1);
+	else
+		libvlc_media_player_previous_chapter(vlcMediaPlayer);
 
 	if ((libvlc_media_player_get_title(vlcMediaPlayer) != currentTitle) ||
 	    (libvlc_media_player_get_chapter(vlcMediaPlayer) != currentChapter)) {
@@ -466,7 +525,10 @@ bool VlcMediaWidget::jumpToNextChapter()
 {
 	int currentTitle = libvlc_media_player_get_title(vlcMediaPlayer);
 	int currentChapter = libvlc_media_player_get_chapter(vlcMediaPlayer);
-	libvlc_media_player_next_chapter(vlcMediaPlayer);
+	if (urlIsAudioCd)
+		playDirection(1);
+	else
+		libvlc_media_player_next_chapter(vlcMediaPlayer);
 
 	if ((libvlc_media_player_get_title(vlcMediaPlayer) != currentTitle) ||
 	    (libvlc_media_player_get_chapter(vlcMediaPlayer) != currentChapter)) {
@@ -507,6 +569,8 @@ int VlcMediaWidget::updatePlaybackStatus()
 		playbackStatus = MediaWidget::Paused;
 		break;
 	case libvlc_Ended:
+		playDirection(1);
+		break;
 	case libvlc_Error:
 		playbackStatus = MediaWidget::Idle;
 		// don't keep last picture shown
@@ -564,6 +628,10 @@ void VlcMediaWidget::updateMetadata()
 		metadata.insert(MediaWidget::TrackNumber,
 			QString::fromUtf8(libvlc_media_get_meta(media, libvlc_meta_TrackNumber)));
 	}
+
+	if (urlIsAudioCd)
+		metadata.insert(MediaWidget::Title,
+				i18n("CD track ") + QString::number(trackNumber));
 }
 
 void VlcMediaWidget::updateAudioStreams()
