@@ -21,11 +21,10 @@
 #ifndef VLCMEDIAWIDGET_H
 #define VLCMEDIAWIDGET_H
 
+#include <vlc/vlc.h>
+
 #include "../abstractmediawidget.h"
 
-class libvlc_event_t;
-class libvlc_instance_t;
-class libvlc_media_player_t;
 class QTimer;
 
 class VlcMediaWidget : public AbstractMediaWidget
@@ -68,6 +67,8 @@ public:
 	bool jumpToNextChapter();
 	void showDvdMenu();
 	void dvdNavigate(int key);
+	void playDirection(int direction);
+	int makePlay();
 
 	int updatePlaybackStatus();
 	void updateCurrentTotalTime();
@@ -90,10 +91,14 @@ private:
 	static void vlcEventHandler(const libvlc_event_t *event, void *instance);
 
 	libvlc_instance_t *vlcInstance;
+	libvlc_media_t *vlcMedia;
 	libvlc_media_player_t *vlcMediaPlayer;
 	bool playingDvd;
 	bool mouseVisible;
 	QMap<int, int> subtitleId;
+	QByteArray typeOfDevice;
+	bool urlIsAudioCd;
+	int trackNumber = 1, numTracks;
 };
 
 #endif /* VLCMEDIAWIDGET_H */
