@@ -23,6 +23,8 @@
 
 #include <QPointer>
 #include <QTimer>
+#include <QList>
+#include <QIcon>
 #include <config-kaffeine.h>
 #include "../tabbase.h"
 #include "../mediawidget.h"
@@ -77,14 +79,17 @@ private slots:
 	void previousChannel();
 	void nextChannel();
 	void cleanTimeShiftFiles();
+	void channelPidsUpdated(const DvbSharedChannel &updatedChannel);
 
 private:
 	void activate();
 	void playChannel(const DvbSharedChannel &channel, const QModelIndex &index);
+	DvbSharedRecording *getInstantRecording(DvbSharedChannel ch);
 
 	MediaWidget *mediaWidget;
 	DvbManager *manager;
 	QAction *instantRecordAction;
+	QList<DvbSharedRecording> instantRecordings;
 	DvbSharedRecording instantRecording;
 	QSplitter *splitter;
 	QWidget *leftWidget;
@@ -96,6 +101,8 @@ private:
 	QTimer osdChannelTimer;
 	QString currentChannel;
 	QString lastChannel;
+	QIcon mediaRecordIcon;
+	QIcon documentSaveIcon;
 	bool autoHideMenu;
 	QTimer *cursorHideTimer;
 
