@@ -97,10 +97,17 @@ namespace IsoCodes
 	*/
 	static QHash<QString, QString> iso639_2_codes;
 
-	bool getLanguage(const QString &code, QString *language)
+	bool getLanguage(const QString &iso_code, QString *language)
 	{
 		static bool first = true;
 
+		QString code = iso_code.toUpper();
+
+		if (code == "QAA") {
+			*language = i18n("Original Language");
+			return true;
+		}
+
 		if (first) {
 			load(iso639_2_codes,
 			     QString("xml/iso-codes/iso_639-2.xml"),
@@ -113,6 +120,21 @@ namespace IsoCodes
 
 		QHash<QString, QString>::ConstIterator it = iso639_2_codes.constFind(code);
 		if (it == iso639_2_codes.constEnd()) {
+			/*
+			 * The ETSI EN 300 468 Annex F spec defines the
+			 * original audio soundtrack code to be "QAA". Yet,
+			 * TV bundle providers could use something else.
+			 *
+			 * At least here, my provider actually uses "ORG"
+			 * instead. Currently, this is an unused ISO 639
+			 * code, so we can safely accept it as well,
+			 * at least as a fallback code while ISO doesn't
+			 * define it.
+			 */
+			if (code == "ORG") {
+				*language = i18n("Original Language");
+				return true;
+			}
 			return false;
 		}
 
