@@ -474,6 +474,7 @@ MainWindow::MainWindow(KAboutData *aboutData, QCommandLineParser *parser)
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("audiocd"), i18n("Play Audio CD")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("videocd"), i18n("Play Video CD")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("dvd"), i18n("Play DVD")));
+	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("aspectratio"), "Force starting with an specific aspect ratio", QLatin1String("aspect ratio")));
 
 #if HAVE_DVB == 1
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("dumpdvb"), i18nc("command line option", "Dump dvb data (debug option)")));
@@ -486,87 +487,7 @@ MainWindow::MainWindow(KAboutData *aboutData, QCommandLineParser *parser)
 
 void MainWindow::parseArgs(const QString workingDirectory)
 {
-	if (parser->isSet("audiocd")) {
-		if (parser->positionalArguments().count() > 0) {
-			openAudioCd(parser->positionalArguments().first());
-		} else {
-			openAudioCd();
-		}
-		return;
-	}
-
-	if (parser->isSet("videocd")) {
-		if (parser->positionalArguments().count() > 0) {
-			openVideoCd(parser->positionalArguments().first());
-		} else {
-			openVideoCd();
-		}
-		return;
-	}
-
-	if (parser->isSet("dvd")) {
-		if (parser->positionalArguments().count() > 0) {
-			openDvd(parser->positionalArguments().first());
-		} else {
-			openDvd();
-		}
-		return;
-	}
-
-#if HAVE_DVB == 1
-	QString channel;
-
-	if (parser->isSet("dumpdvb")) {
-		dvbTab->enableDvbDump();
-	}
-
-	channel = parser->value("channel");
-
-	if (!channel.isEmpty()) {
-		activateTab(DvbTabId);
-		dvbTab->playChannel(channel);
-
-		return;
-	}
-
-	channel = parser->value("tv");
-	if (!channel.isEmpty()) {
-		activateTab(DvbTabId);
-		dvbTab->playChannel(channel);
-
-		return;
-	}
-
-	if (parser->isSet("lastchannel")) {
-		activateTab(DvbTabId);
-		dvbTab->playLastChannel();
-
-		return;
-	}
-#endif /* HAVE_DVB == 1 */
-
-	if (parser->positionalArguments().count() > 0) {
-		QList<QUrl> urls;
-
-		for (int i = 0; i < parser->positionalArguments().count(); ++i) {
-			QUrl url = QUrl::fromUserInput(parser->positionalArguments().at(i), workingDirectory);
-
-			if (url.isValid()) {
-				urls.append(url);
-			}
-		}
-
-		if (parser->isSet("tempfile")) {
-			temporaryUrls.append(urls);
-		}
-
-		if (urls.size() >= 2) {
-			activateTab(PlaylistTabId);
-			playlistTab->appendToVisiblePlaylist(urls, true);
-		} else if (!urls.isEmpty()) {
-			openUrl(urls.at(0));
-		}
-	}
+	/* Parse first arguments that aren't mutually exclusive */
 
 	if (parser->isSet("alwaysontop")) {
 		Qt::WindowFlags flags = this->windowFlags();
@@ -609,6 +530,122 @@ void MainWindow::parseArgs(const QString workingDirectory)
 		} /* case */
 		} /* switch */
 	}
+
+	if (parser->isSet("aspectratio")) {
+		MediaWidget::AspectRatio aspectRatio = MediaWidget::AspectRatioAuto;
+		QString aspect;
+
+		aspect = parser->value("aspectratio");
+
+		if (aspect == "1:1")
+			aspectRatio = MediaWidget::AspectRatio1_1;
+		else if (aspect == "4:3")
+			aspectRatio = MediaWidget::AspectRatio4_3;
+		else if (aspect == "5:4")
+			aspectRatio = MediaWidget::AspectRatio5_4;
+		else if (aspect == "16:9")
+			aspectRatio = MediaWidget::AspectRatio16_9;
+		else if (aspect == "16:10")
+			aspectRatio = MediaWidget::AspectRatio16_10;
+		else if (aspect == "2.21:1")
+			aspectRatio = MediaWidget::AspectRatio221_100;
+		else if (aspect == "2.35:1")
+			aspectRatio = MediaWidget::AspectRatio235_100;
+		else if (aspect == "2.39:1")
+			aspectRatio = MediaWidget::AspectRatio239_100;
+
+		mediaWidget->setAspectRatio(aspectRatio);
+	}
+
+
+#if HAVE_DVB == 1
+	if (parser->isSet("dumpdvb")) {
+		dvbTab->enableDvbDump();
+	}
+#endif
+
+	/*
+	 * Now, parse arguments that are mutually exclusive
+	 */
+
+#if HAVE_DVB == 1
+	QString channel;
+
+	channel = parser->value("channel");
+
+	if (!channel.isEmpty()) {
+		activateTab(DvbTabId);
+		dvbTab->playChannel(channel);
+
+		return;
+	}
+
+	channel = parser->value("tv");
+	if (!channel.isEmpty()) {
+		activateTab(DvbTabId);
+		dvbTab->playChannel(channel);
+
+		return;
+	}
+
+	if (parser->isSet("lastchannel")) {
+		activateTab(DvbTabId);
+		dvbTab->playLastChannel();
+
+		return;
+	}
+#endif /* HAVE_DVB == 1 */
+
+	if (parser->isSet("audiocd")) {
+		if (parser->positionalArguments().count() > 0) {
+			openAudioCd(parser->positionalArguments().first());
+		} else {
+			openAudioCd();
+		}
+		return;
+	}
+
+	if (parser->isSet("videocd")) {
+		if (parser->positionalArguments().count() > 0) {
+			openVideoCd(parser->positionalArguments().first());
+		} else {
+			openVideoCd();
+		}
+		return;
+	}
+
+	if (parser->isSet("dvd")) {
+		if (parser->positionalArguments().count() > 0) {
+			openDvd(parser->positionalArguments().first());
+		} else {
+			openDvd();
+		}
+		return;
+	}
+
+	if (parser->positionalArguments().count() > 0) {
+		QList<QUrl> urls;
+
+		for (int i = 0; i < parser->positionalArguments().count(); ++i) {
+			QUrl url = QUrl::fromUserInput(parser->positionalArguments().at(i), workingDirectory);
+
+			if (url.isValid()) {
+				urls.append(url);
+			}
+		}
+
+		if (parser->isSet("tempfile")) {
+			temporaryUrls.append(urls);
+		}
+
+		if (urls.size() >= 2) {
+			activateTab(PlaylistTabId);
+			playlistTab->appendToVisiblePlaylist(urls, true);
+		} else if (!urls.isEmpty()) {
+			openUrl(urls.at(0));
+		}
+		return;
+	}
 }
 
 void MainWindow::displayModeChanged()
