@@ -793,14 +793,14 @@ void MediaWidget::previous()
 {
 	if (source->getType() == MediaSource::Url)
 		emit playlistPrevious();
-	source->previous();
+	backend->jumpToPreviousChapter();
 }
 
 void MediaWidget::next()
 {
 	if (source->getType() == MediaSource::Url)
 		emit playlistNext();
-	source->next();
+	backend->jumpToNextChapter();
 }
 
 void MediaWidget::stop()
@@ -991,6 +991,13 @@ void MediaWidget::aspectRatioChanged(QAction *action)
 	qCWarning(logMediaWidget, "internal error");
 }
 
+
+void MediaWidget::setAspectRatio(MediaWidget::AspectRatio aspectRatio)
+{
+	backend->setAspectRatio(aspectRatio);
+}
+
+
 void MediaWidget::setVideoSize()
 {
 	float scale = autoResizeFactor / 100.0;
